// simple test module (used by testImporter.js)

/* exported bar, foo */

var foo = 'This is foo';
var bar = 'This is bar';
